Developed and maintained by `Hearsay Social, Inc.
<http://hearsaysocial.com>`_.

Contributors
============
| `Adam DePue <http://github.com/adepue>`_
| `Akshay Shah <http://github.com/akshayjshah>`_
| `John Lynn <http://github.com/jlynn>`_
| `Dylan Verheul <http://github.com/dyve>`_
| `Grant McConnaughey <http://github.com/grantmcconnaughey>`_
